@@ -370,27 +370,17 @@ class SkyCoord(ShapedLikeNDArray):
     def representation_type(self, value):
         self.frame.representation_type = value
 
-    # TODO: remove these in future
-    @property
-    def representation(self):
-        return self.frame.representation
-
-    @representation.setter
-    def representation(self, value):
-        self.frame.representation = value
-
     @property
     def shape(self):
         return self.frame.shape
 
     def __eq__(self, value):
-        """Equality operator for SkyCoord
+        """Equality operator for SkyCoord.
 
         This implements strict equality and requires that the frames are
         equivalent, extra frame attributes are equivalent, and that the
         representation data are exactly equal.
         """
-
         if isinstance(value, BaseCoordinateFrame):
             if value._data is None:
                 raise ValueError("Can only compare SkyCoord to Frame with data")
@@ -474,7 +464,7 @@ class SkyCoord(ShapedLikeNDArray):
         return new
 
     def __setitem__(self, item, value):
-        """Implement self[item] = value for SkyCoord
+        """Implement self[item] = value for SkyCoord.
 
         The right hand ``value`` must be strictly consistent with self:
         - Identical class
@@ -716,11 +706,12 @@ class SkyCoord(ShapedLikeNDArray):
         return self.__class__(new_coord, **frame_kwargs)
 
     def apply_space_motion(self, new_obstime=None, dt=None):
-        """
+        """Compute the position to a new time using the velocities.
+
         Compute the position of the source represented by this coordinate object
         to a new time using the velocities stored in this object and assuming
         linear space motion (including relativistic corrections). This is
-        sometimes referred to as an "epoch transformation."
+        sometimes referred to as an "epoch transformation".
 
         The initial time before the evolution is taken from the ``obstime``
         attribute of this coordinate.  Note that this method currently does not
@@ -892,10 +883,8 @@ class SkyCoord(ShapedLikeNDArray):
             if frame_cls is not None and self.frame.is_transformable_to(frame_cls):
                 return self.transform_to(attr)
 
-        # Fail
-        raise AttributeError(
-            f"'{self.__class__.__name__}' object has no attribute '{attr}'"
-        )
+        # Call __getattribute__; this will give correct exception.
+        return self.__getattribute__(attr)
 
     def __setattr__(self, attr, val):
         # This is to make anything available through __getattr__ immutable
@@ -950,10 +939,12 @@ class SkyCoord(ShapedLikeNDArray):
             super().__delattr__(attr)
 
     def __dir__(self):
-        """
-        Override the builtin `dir` behavior to include:
-        - Transforms available by aliases
-        - Attribute / methods of the underlying self.frame object
+        """Original dir() behavior, plus frame attributes and transforms.
+
+        This dir includes:
+        - All attributes of the SkyCoord class
+        - Coordinate transforms available by aliases
+        - Attribute / methods of the underlying self.frame objects
         """
         dir_values = set(super().__dir__())
 
@@ -1013,7 +1004,6 @@ class SkyCoord(ShapedLikeNDArray):
         **kwargs
             Keyword args passed to :meth:`~astropy.coordinates.Angle.to_string`.
         """
-
         sph_coord = self.frame.represent_as(SphericalRepresentation)
 
         styles = {
@@ -1740,7 +1730,7 @@ class SkyCoord(ShapedLikeNDArray):
         To determine which constellation a point on the sky is in, this first
         precesses to B1875, and then uses the Delporte boundaries of the 88
         modern constellations, as tabulated by
-        `Roman 1987 <http://cdsarc.u-strasbg.fr/viz-bin/Cat?VI/42>`_.
+        `Roman 1987 <https://cdsarc.cds.unistra.fr/viz-bin/Cat?VI/42>`_.
 
         See Also
         --------
@@ -1830,7 +1820,7 @@ class SkyCoord(ShapedLikeNDArray):
         wcs : `~astropy.wcs.WCS`
             The coordinate to check if it is within the wcs coordinate.
         image : array
-            Optional.  The image associated with the wcs object that the cooordinate
+            Optional.  The image associated with the wcs object that the coordinate
             is being checked against. If not given the naxis keywords will be used
             to determine if the coordinate falls within the wcs footprint.
         **kwargs
@@ -1841,7 +1831,6 @@ class SkyCoord(ShapedLikeNDArray):
         response : bool
             True means the WCS footprint contains the coordinate, False means it does not.
         """
-
         if image is not None:
             ymax, xmax = image.shape
         else:
@@ -2212,7 +2201,6 @@ class SkyCoord(ShapedLikeNDArray):
         coord : SkyCoord
             Instance of the SkyCoord class.
         """
-
         from .name_resolve import get_icrs_coordinates
 
         icrs_coord = get_icrs_coordinates(name, parse, cache=cache)
